-- OV_ArenaMute (c) 2010 perikles
-- Prevents arena messages from spamming the chat frame

local addon_name = "OV_ArenaMute"
OV_ArenaMuteFilterState = true -- current state of the filter (on/off). saved across sessions

local filters =  -- what the filter is listening for; a message gets filtered if one of these patterns match
{ 
	"%[Arena Sprecher%]"
}

local frame = CreateFrame("Frame", addon_name)

function frame:FilterArenaMsg(event, msg)
	if not OV_ArenaMuteFilterState then
		return false -- let all messages pass if filtering is disabled
	end
	
	for index, text in ipairs(filters) do
		if msg:find(text) ~= nil then
			return true -- pattern matches, do not show message
		end
	end
	
	return false
end

function frame:FilterOn()
	OV_ArenaMuteFilterState = true
end

function frame:FilterOff()
	OV_ArenaMuteFilterState = false
end

function frame:ShowFilterState()
	if OV_ArenaMuteFilterState then
		print("Der OV Arena-Sprecher wird \124cffff0000nicht angezeigt\124h\124r.")
	else
		print("Der OV Arena-Sprecher wird \124cff00ff00angezeigt\124h\124r.")
	end
end

function frame:ShowHelp()
	self:ShowFilterState()
	print("Anzeigen: \124cffffff00/ovarena on\124h\124r    Nicht anzeigen: \124cffffff00/ovarena off\124h\124r")
end

function frame:AddonLoaded(event, name)
	-- show state and help at startup
	if name == addon_name then
		self:ShowHelp()
	end
end

function frame:EventHandler(event, ...)
	if event == "ADDON_LOADED" then
		self:AddonLoaded(event, ...)
	end
end

function frame.SlashCommand(msg)
	if msg == "on" or msg == "an" then
		frame:FilterOff()
		frame:ShowFilterState()
	elseif msg == "off" or msg == "aus" then
		frame:FilterOn()
		frame:ShowFilterState()
	else	
		frame:ShowHelp()
	end
end

-- listen for loaded event to display help at startup
frame:RegisterEvent("ADDON_LOADED", frame.AddonLoaded)
frame:SetScript("OnEvent", frame.EventHandler);

-- add chat filter
ChatFrame_AddMessageEventFilter("CHAT_MSG_SYSTEM", frame.FilterArenaMsg)

-- add slash command
SLASH_OVARENA1 = "/ovarena"
SlashCmdList["OVARENA"] = frame.SlashCommand
